==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/ProfileCardAnnotation.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

import odata.msgraph.client.beta.schema.SchemaInfo;

@JsonPropertyOrder({
    "@odata.type", 
    "displayName", 
    "localizations"})
@JsonInclude(Include.NON_NULL)
public class ProfileCardAnnotation implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("displayName")
    protected String displayName;

    @JsonProperty("localizations")
    protected List<DisplayNameLocalization> localizations;

    @JsonProperty("localizations@nextLink")
    protected String localizationsNextLink;

    protected ProfileCardAnnotation() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.profileCardAnnotation";
    }

    @Property(name="displayName")
    @JsonIgnore
    public Optional<String> getDisplayName() {
        return Optional.ofNullable(displayName);
    }

    public ProfileCardAnnotation withDisplayName(String displayName) {
        ProfileCardAnnotation _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.profileCardAnnotation");
        _x.displayName = displayName;
        return _x;
    }

    @Property(name="localizations")
    @JsonIgnore
    public CollectionPage<DisplayNameLocalization> getLocalizations() {
        return new CollectionPage<DisplayNameLocalization>(contextPath, DisplayNameLocalization.class, localizations, Optional.ofNullable(localizationsNextLink), SchemaInfo.INSTANCE, Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    @Property(name="localizations")
    @JsonIgnore
    public CollectionPage<DisplayNameLocalization> getLocalizations(HttpRequestOptions options) {
        return new CollectionPage<DisplayNameLocalization>(contextPath, DisplayNameLocalization.class, localizations, Optional.ofNullable(localizationsNextLink), SchemaInfo.INSTANCE, Collections.emptyList(), options);
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String displayName;
        private List<DisplayNameLocalization> localizations;
        private String localizationsNextLink;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder displayName(String displayName) {
            this.displayName = displayName;
            this.changedFields = changedFields.add("displayName");
            return this;
        }

        public Builder localizations(List<DisplayNameLocalization> localizations) {
            this.localizations = localizations;
            this.changedFields = changedFields.add("localizations");
            return this;
        }

        public Builder localizations(DisplayNameLocalization... localizations) {
            return localizations(Arrays.asList(localizations));
        }

        public Builder localizationsNextLink(String localizationsNextLink) {
            this.localizationsNextLink = localizationsNextLink;
            this.changedFields = changedFields.add("localizations");
            return this;
        }

        public ProfileCardAnnotation build() {
            ProfileCardAnnotation _x = new ProfileCardAnnotation();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.profileCardAnnotation";
            _x.displayName = displayName;
            _x.localizations = localizations;
            _x.localizationsNextLink = localizationsNextLink;
            return _x;
        }
    }

    private ProfileCardAnnotation _copy() {
        ProfileCardAnnotation _x = new ProfileCardAnnotation();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.displayName = displayName;
        _x.localizations = localizations;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("ProfileCardAnnotation[");
        b.append("displayName=");
        b.append(this.displayName);
        b.append(", ");
        b.append("localizations=");
        b.append(this.localizations);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/complex/ProfileCardAnnotation.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "displayName", 
    "localizations"})
@JsonInclude(Include.NON_NULL)
public class ProfileCardAnnotation implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("displayName")
    protected String displayName;

    @JsonProperty("localizations")
    protected List<DisplayNameLocalization> localizations;

    @JsonProperty("localizations@nextLink")
    protected String localizationsNextLink;

    protected ProfileCardAnnotation() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.profileCardAnnotation";
    }

    @Property(name="displayName")
    @JsonIgnore
    public Optional<String> getDisplayName() {
        return Optional.ofNullable(displayName);
    }

    public ProfileCardAnnotation withDisplayName(String displayName) {
        ProfileCardAnnotation _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.profileCardAnnotation");
        _x.displayName = displayName;
        return _x;
    }

    @Property(name="localizations")
    @JsonIgnore
    public CollectionPage<DisplayNameLocalization> getLocalizations() {
        return new CollectionPage<DisplayNameLocalization>(contextPath, DisplayNameLocalization.class, this.localizations, Optional.ofNullable(localizationsNextLink), Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    @Property(name="localizations")
    @JsonIgnore
    public CollectionPage<DisplayNameLocalization> getLocalizations(HttpRequestOptions options) {
        return new CollectionPage<DisplayNameLocalization>(contextPath, DisplayNameLocalization.class, this.localizations, Optional.ofNullable(localizationsNextLink), Collections.emptyList(), options);
    }

    public ProfileCardAnnotation withUnmappedField(String name, Object value) {
        ProfileCardAnnotation _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String displayName;
        private List<DisplayNameLocalization> localizations;
        private String localizationsNextLink;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder displayName(String displayName) {
            this.displayName = displayName;
            this.changedFields = changedFields.add("displayName");
            return this;
        }

        public Builder localizations(List<DisplayNameLocalization> localizations) {
            this.localizations = localizations;
            this.changedFields = changedFields.add("localizations");
            return this;
        }

        public Builder localizations(DisplayNameLocalization... localizations) {
            return localizations(Arrays.asList(localizations));
        }

        public Builder localizationsNextLink(String localizationsNextLink) {
            this.localizationsNextLink = localizationsNextLink;
            this.changedFields = changedFields.add("localizations");
            return this;
        }

        public ProfileCardAnnotation build() {
            ProfileCardAnnotation _x = new ProfileCardAnnotation();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.profileCardAnnotation";
            _x.displayName = displayName;
            _x.localizations = localizations;
            _x.localizationsNextLink = localizationsNextLink;
            return _x;
        }
    }

    private ProfileCardAnnotation _copy() {
        ProfileCardAnnotation _x = new ProfileCardAnnotation();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.displayName = displayName;
        _x.localizations = localizations;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("ProfileCardAnnotation[");
        b.append("displayName=");
        b.append(this.displayName);
        b.append(", ");
        b.append("localizations=");
        b.append(this.localizations);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
